/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or (at
 *  your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *  MA 02110-1301, USA.
 *
 *  Copyright © 2006 Pierre Habouzit
 */

/*
 * Copyright notice from original mutt:
 * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
 * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
 *
 * This file is part of mutt-ng, see http://www.muttng.org/.
 * It's licensed under the GNU General Public License,
 * please see the file GPL in the top level source directory.
 */

#ifndef MUTT_LIB_MIME_MIME_H
#define MUTT_LIB_MIME_MIME_H

#include <stdlib.h>

#include "mime-types.h"

extern const char MimeSpecials[];
extern const char *BodyTypes[];
extern const char *BodyEncodings[];

/* MIME encoding/decoding global vars */

#define is_multipart(x) \
    ((x)->type == TYPEMULTIPART \
     || ((x)->type == TYPEMESSAGE && (!strcasecmp((x)->subtype, "rfc822") \
                                      || !strcasecmp((x)->subtype, "news"))))
#define TYPE(X) ((X->type == TYPEOTHER) && (X->xtype != NULL) ? X->xtype : BodyTypes[(X->type)])
#define ENCODING(X) BodyEncodings[(X)]

/****************************************************************************/
/* RFC 822                                                                  */
/*                Standard for ARPA Internet Text Messages                  */
/****************************************************************************/

address_t *address_dup(address_t *addr);
address_t *address_list_dup(address_t *addr);
void rfc822_qualify(address_t *, const char *);

address_t *rfc822_parse_adrlist(address_t *, const char *s);

ssize_t rfc822_write_address(char *, ssize_t, address_t *, int);
ssize_t rfc822_write_address_single(char *, ssize_t, address_t *, int);
ssize_t rfc822_strcpy(char *, ssize_t, const char *, const char *);

extern const char RFC822Specials[];

/****************************************************************************/
/* RFC 2047                                                                 */
/*       MIME (Multipurpose Internet Mail Extensions) Part Three:           */
/*             Message Header Extensions for Non-ASCII Text                 */
/****************************************************************************/

char *mutt_choose_charset(const char *fromcode, const char *charsets,
                          char *u, ssize_t ulen, char **d, ssize_t *dlen);

void rfc2047_encode_string(char **);
void rfc2047_encode_adrlist(address_t *, const char *);

void rfc2047_decode(char **);
void rfc2047_decode_adrlist(address_t *);
void rfc2047_decode_envelope(ENVELOPE* e);

/****************************************************************************/
/* RFC 2231                                                                 */
/*             MIME Parameter Value and Encoded Word Extensions:            */
/*               Character Sets, Languages, and Continuations               */
/****************************************************************************/

int  rfc2231_encode_string(char **);
void rfc2231_decode_parameters(PARAMETER **);

#endif /* MUTT_LIB_MIME_MIME_H */
